pub struct Move {
pub item: String,
pub from: String,
pub to: String,
}Expand description
A committed drag-move: item item left zone from and landed in zone to.
The host applies each as a real transition (and may reject it, then re-place).
Fields
item: Stringfrom: Stringto: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Move
impl<'de> Deserialize<'de> for Move
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Move
impl StructuralPartialEq for Move