pub enum Action {
Show 36 variants
Copy,
Cut,
Paste,
SelectAll,
Undo,
Redo,
Find,
Save,
Confirm,
Cancel,
Left,
Right,
Up,
Down,
WordLeft,
WordRight,
LineStart,
LineEnd,
DocStart,
DocEnd,
PageUp,
PageDown,
ExtendLeft,
ExtendRight,
ExtendUp,
ExtendDown,
ZoomIn,
ZoomOut,
FitToView,
FocusNext,
FocusPrev,
FocusLeft,
FocusRight,
FocusUp,
FocusDown,
FocusHints,
}Expand description
The single semantic action vocabulary shared by every facett component
(COH-2). A given action is the same chord in every component because the
chord lives only here, in the KeyMap.
Variants
Copy
Cut
Paste
SelectAll
Undo
Redo
Find
Save
Confirm
Cancel
Left
Right
Up
Down
WordLeft
WordRight
LineStart
LineEnd
DocStart
DocEnd
PageUp
PageDown
ExtendLeft
ExtendRight
ExtendUp
ExtendDown
ZoomIn
ZoomOut
FitToView
FocusNext
FocusPrev
FocusLeft
FocusRight
FocusUp
FocusDown
FocusHints
Toggle the focus-hint overlay (FOC-3) / which-key trigger.
Implementations